#!/usr/bin/env python

from distutils.core import setup
import os

setup(name='touchsearch-dictionary',
   version='1.0',
   data_files = [
      ('/opt/touchsearch/search_engines/Dictionary/',['Dictionary.search', 'dictionary_color.png', 'dictionary_ghosted.png'])
      ]
      )